<?php
	
	/*
		Die nachfolgende Klasse wird im Beitrag https://www.codepalm.de/post/atomare-webseiten-struktur-mit-html-und-php/ detailliert erklärt.
	*/

	abstract class Structure {
		
		protected $structure_file_path;
		protected $replacements;
		function __construct( string $structure_file_path = "", array $replacements = array() ) {
			
			$this->structure_file_path = $structure_file_path;
			$this->replacements = $replacements;
			
		}
		
		public function get_content_container() {
			
			$container_structure = $this->get_container_structure();
			$container_replacements = $this->get_container_replacements();
			
			$parsed_container = $this->replace_strings(
				$container_structure,
				$container_replacements
			);
			
			return $this->clean_placeholders( $parsed_container );
			
		}
		
		protected function replace_strings( string $structure, array $replacements = array() ) {
			
			foreach( $replacements as $placeholder => $replacement ) {
				
				$placeholder = "%$placeholder%";
				$structure = str_replace( $placeholder, $replacement, $structure );
				
			}
			
			return $structure;
			
		}
		
		protected function get_container_replacements() {
			
			$container_replacements = $this->replacements;
			return $container_replacements;
			
		}
		
		abstract protected function get_container_structure();
		
		protected function get_container_structure_from_file() {
			
			$structure = "";
			if( !empty( $this->structure_file_path ) && file_exists( $this->structure_file_path ) ) {
				$structure = file_get_contents( $this->structure_file_path );
			}
			
			return $structure;
			
		}
		
		protected function get_classes( array $classes = array() ) {
			
			$classes = trim( join( " ", $classes ) );
			return "class='$classes'";
			
		}
		
		protected function clean_placeholders( string $structure = "" ) {
			
			return preg_replace( "/\%[^\%]*\%/", '', $structure );
			
		}
		
	}
	
?>
